__name__ = 'kw618'
__description__ = 'integrated several packages for myself to use'
__version__ = '0.0.1'
__author__ = "Kerwin Lui"
__author_email__ = 'kerwin19950830@gmail.com'
__copyright__ = 'Copyright 2020 Kerwin Lui'
